@@ -4,4 +4,5 @@ Importing the main.py will start interactive demo of the package.
 """
 
 
-import main as _; del _
+from play import run
+run()
